package net.sf.sql2java.common.parameters.handlers;

import java.util.Map;
import java.util.regex.Matcher;

import net.sf.sql2java.utils.StringUtils;

import org.apache.log4j.Logger;

public class SimpleMapParameterHandler implements ParameterHandler {
	public static final Logger LOGGER = Logger.getLogger(SimpleMapParameterHandler.class);
	private Map<String, String> properties;
	
// -- Constructors ------------------------------------------------------------
	
	public SimpleMapParameterHandler(Map<String, String> properties) {
		this.properties = properties;
	}
	
// -- Elegible Methods --------------------------------------------------------
	
	@Override
	public boolean isElegible(String parameter) {
		return true;
	}
	
// -- Parameter Substitution --------------------------------------------------

	@Override
	public String onParameter(String content, String parameter) {
		// -- create the result
		String result = content;
		
		// -- lookup the parameter
		String replacement = properties.get(parameter);
		
		// -- check if the parameter is null
		if (replacement == null) return content;
		
		// -- replace all occurrences of the parameter with the replacement
		result = result.replaceAll(
				StringUtils.parameterize(parameter), 
				Matcher.quoteReplacement(replacement)
		);
		
		// -- return the result
		return result;
	}
}
