package net.sf.sql2java.generator;

import java.util.HashMap;
import java.util.Map;

import net.sf.sql2java.common.parameters.StringParser;
import net.sf.sql2java.common.parameters.handlers.ContextParameterHandler;
import net.sf.sql2java.common.resources.Resource;
import net.sf.sql2java.conversion.Convertor;
import net.sf.sql2java.conversion.KeywordGroup;
import net.sf.sql2java.data.node.Nodelet;
import net.sf.sql2java.generator.template.Template;
import net.sf.sql2java.generator.template.pack.TemplatePack;

public class GeneratorSupport {
	private StringParser parser;
	
	private Convertor convertor;
	private TemplatePack templatePack;

// -- Constructors ------------------------------------------------------------
	
	public GeneratorSupport(GeneratorCycle cycle, Convertor convertor, TemplatePack templatePack) {
		this.convertor = convertor;
		this.templatePack = templatePack;
		this.parser = new StringParser(
				new ContextParameterHandler(cycle.getProperties())
		);
	}
	
// -- Template Resources ------------------------------------------------------
	
	public String getRelativeTemplateDirectory(String templateName) {
		return getRelativeTemplateDirectory(getTemplate(templateName));
	}
	
	public String getRelativeTemplateDirectory(Template template) {
		// -- create the resource object
		Resource result = new Resource();
		
		// -- append the parts
		result.append(convertor.translateTo(KeywordGroup.JAVA, template.getPath()));
		
		// -- parse and return the result
		return parser.parse(result.getPath());
	}
	
	public String getRelativeTemplateFile(String templateName) {
		return getRelativeTemplateFile(getTemplate(templateName));
	}
	
	public String getRelativeTemplateFile(Template template) {
		// -- create the resource object
		Resource result = new Resource();
		
		// -- append the parts
		result.append(convertor.translateTo(KeywordGroup.JAVA, template.getPath()));
		result.append(convertor.translateTo(KeywordGroup.JAVA, template.getEntityName()));
		result.addRaw(convertor.translateTo(KeywordGroup.JAVA, template.getExtension()));
		
		// -- parse and return the result
		return parser.parse(result.getPath());
	}
	
// -- Helper Methods ----------------------------------------------------------
	
	public Template getTemplate(String templateName) {
		// -- get the template with the given name
		Template result = templatePack.getTemplate(templateName);
		
		// -- check if the template is valid
		if (result == null) 
			throw new RuntimeException(
					String.format("No template found with name %s", templateName)
			);
		
		// -- return the result
		return result;
	}

	public String parse(String input) {
		return parser.parse(input);
	}
	
	public String parseNodelet(String input, Nodelet nodelet) {
		// -- create the context
		Map<String, Object> context = new HashMap<String, Object>();
		context.put(nodelet.getType(), nodelet);

		// -- create the parser
		StringParser np = new StringParser(
				new ContextParameterHandler(context)
		);
		
		// -- parse the message
		return np.parse(input);
	}
}
